@@ -12,15 +12,22 @@ fn timer_schedule_once() {
     };
 
     let timer = Timer::new(Callback::closure(cb)).expect("To create timer");
+    assert!(!timer.is_scheduled());
     timer.schedule_once(time::Duration::from_millis(250));
+    assert!(timer.is_scheduled());
 
     std::thread::sleep(time::Duration::from_millis(1000));
 
     assert_eq!(COUNT.load(Ordering::Acquire), 1);
 
+    #[cfg(all(unix, not(any(target_os = "macos", target_os = "ios"))))]
+    assert!(!timer.is_scheduled());
+
     timer.schedule_once(time::Duration::from_millis(250));
     timer.cancel();
 
+    assert!(!timer.is_scheduled());
+
     std::thread::sleep(time::Duration::from_millis(1000));
     assert_eq!(COUNT.load(Ordering::Acquire), 1);
 }
@@ -34,14 +41,19 @@ fn timer_schedule_interval() {
     }
 
     let timer = Timer::new(Callback::plain(cb)).expect("To create timer");
+    assert!(!timer.is_scheduled());
     timer.schedule_interval(time::Duration::from_secs(1), time::Duration::from_millis(300));
+    assert!(timer.is_scheduled());
 
     std::thread::sleep(time::Duration::from_millis(1100));
     assert_eq!(COUNT.load(Ordering::Acquire), 1);
+    assert!(timer.is_scheduled());
     std::thread::sleep(time::Duration::from_millis(1100));
     assert_eq!(COUNT.load(Ordering::Acquire), 5);
+    assert!(timer.is_scheduled());
 
     timer.cancel();
+    assert!(!timer.is_scheduled());
 
     std::thread::sleep(time::Duration::from_millis(1100));
     assert_eq!(COUNT.load(Ordering::Acquire), 5);
